==> rice-impex-server-bootstrap-2.5.16-sql.jar: sql/oracle/KRCR_NMSPC_T.sql <==
TRUNCATE TABLE KRCR_NMSPC_T DROP STORAGE
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,APPL_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RICE','Service Bus','KR-BUS','5B960CFDBB370FDFE0404F8189D83CBD',1)
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,APPL_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RICE','Identity Management','KR-IDM','61645D045B0005D7E0404F8189D849B1',1)
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,APPL_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RICE','Kuali Rapid Application Development','KR-KRAD','B5BA065471F8326EE0404F8189D87F9A',1)
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,APPL_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RICE','Kuali Location','KR-LOC','0738D0BC9F5EF57DE0506E0AC31D419D',1)
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,APPL_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RICE','Kuali Nervous System','KR-NS','53680C68F595AD9BE0404F8189D80A6C',1)
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,APPL_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RICE','Notification','KR-NTFCN','5B960CFDBB360FDFE0404F8189D83CBD',1)
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,APPL_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RICE','Kuali Rules','KR-RULE','AE3195EDFF2300E2E0404F8189D822AE',1)
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,APPL_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RICE','Enterprise Infrastructure','KR-SYS','5B960CFDBB390FDFE0404F8189D83CBD',1)
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,APPL_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RICE','Workflow','KR-WKFLW','5E1D690C419B3E2EE0404F8189D82677',0)
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Kuali Systems','KUALI','5ADF18B6D4817954E0404F8189D85002',1)
/

==> rice-impex-server-bootstrap-2.6.3-sql.jar: sql/oracle/KRCR_NMSPC_T.sql <==
TRUNCATE TABLE KRCR_NMSPC_T DROP STORAGE
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,APPL_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RICE','Service Bus','KR-BUS','5B960CFDBB370FDFE0404F8189D83CBD',1)
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,APPL_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RICE','Identity Management','KR-IDM','61645D045B0005D7E0404F8189D849B1',1)
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,APPL_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RICE','Kuali Rapid Application Development','KR-KRAD','B5BA065471F8326EE0404F8189D87F9A',1)
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,APPL_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RICE','Kuali Location','KR-LOC','177BFC79B293E91EE050EC0A6EAC3C2E',1)
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,APPL_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RICE','Kuali Nervous System','KR-NS','53680C68F595AD9BE0404F8189D80A6C',1)
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,APPL_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RICE','Notification','KR-NTFCN','5B960CFDBB360FDFE0404F8189D83CBD',1)
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,APPL_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RICE','Kuali Rules','KR-RULE','AE3195EDFF2300E2E0404F8189D822AE',1)
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,APPL_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RICE','Enterprise Infrastructure','KR-SYS','5B960CFDBB390FDFE0404F8189D83CBD',1)
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,APPL_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RICE','Workflow','KR-WKFLW','5E1D690C419B3E2EE0404F8189D82677',0)
/
INSERT INTO KRCR_NMSPC_T (ACTV_IND,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Kuali Systems','KUALI','5ADF18B6D4817954E0404F8189D85002',1)
/
